@@ -436,6 +436,10 @@ class GeneDc(Gene):
         return super().__repr__() + ', rnc_array=[' + ', '.join(str(num) for num in self.rnc_array) + ']'
 
 
+def _default_linker(*args): 
+    return tuple(args)
+
+
 class Chromosome(list):
     """
     Individual representation in gene expression programming (GEP), which may contain one or more genes. Note that in a
@@ -451,7 +455,7 @@ class Chromosome(list):
         :param n_genes: number of genes
         :param linker: callable, a linking function
 
-        .. note:
+        .. note::
             If a linker is specified, then it must accept *n_genes* arguments, each produced by one gene. If the
             *linker* parameter is the default value ``None``, then for a monogenic chromosome, no linking is applied,
             while for a multigenic chromosome, the ``tuple`` function is used, i.e., a tuple of values of all genes 
@@ -530,6 +534,9 @@ class Chromosome(list):
             returns the value of the single gene for a single-gene (monogenic) chromosome or a tuple of values of all 
             genes for a multi-gene chromosome.
         """
+        # the default linker for a multi-gene chromosome
+        if self._linker is None and len(self) > 1:
+            return _default_linker
         return self._linker
 
     def __repr__(self):
