@@ -112,7 +112,8 @@ class Function(Primitive):
         assert _is_nonkeyword_identifier(name), \
             'Name of a function must be a valid non-keyword Python identifier'
         super().__init__(name, arity)
-        args = ', '.join('{{{}}}'.format(index) for index in range(arity))  # like '{0}, {1}, {2}'
+        args = ', '.join('{{{}}}'.format(index)
+                         for index in range(arity))  # like '{0}, {1}, {2}'
         self._seq = name + '(' + args + ')'  # e.g., add, --> 'add({0}, {1})'
 
     def format(self, *args):
@@ -176,6 +177,7 @@ class ConstantTerminal(Terminal):
     Class that represents a constant terminal, whose value will never change during the whole evolution.
     The value of a constant terminal can only be a literal variable , such as a numeric number or a Boolean variable.
     """
+
     def __init__(self, value):
         """
         Initialize a constant terminal with the given *value*.
@@ -194,6 +196,7 @@ class SymbolTerminal(Terminal):
     :attr:`name` of a symbol terminal must be a valid and unique Python identifier.
     The value of a symbol terminal can be any object that leads to a legal expression when evaluated.
     """
+
     def __init__(self, name):
         """
         Initialize a symbol terminal with the symbol given by *name*.
@@ -208,7 +211,7 @@ class SymbolTerminal(Terminal):
 class EphemeralTerminal(Terminal):
     """
     Class that encapsulates an ephemeral numeric constant terminal in GEP, which can be used to build a normal constant
-    terminal with a randomly produced value when needed using the :meth:`Ephemeral.generate` method.
+    terminal with a randomly produced value when needed using the :meth:`update_value()` method.
 
     Just as the name implies, the value of an ephemeral terminal may be changed during evolution, either by mutation or
     by some local search heuristics, to optimize the numerical constants in a mathematical model.
@@ -219,8 +222,9 @@ class EphemeralTerminal(Terminal):
             GEP is to add a RNC domain in genes and use the GEP-RNC algorithm. See Chapter 5 of [FC2006]_.
 
     .. seealso::
-        :func:`~geppy.tools.mutation.mutate_uniform_ephemeral` for ephemeral mutation, and
-        :class:`~geppy.core.entity.GeneDc` for the GEP-RNC algorithm.
+        :func:`~geppy.tools.mutation.mutate_uniform_ephemeral` for ephemeral mutation, :meth:`PrimitiveSet.add_ephemeral_terminal`
+        to add an ephemeral termination in evolution, 
+        and :class:`~geppy.core.entity.GeneDc` for the GEP-RNC algorithm.
     """
 
     def __init__(self, name, gen):
@@ -374,7 +378,7 @@ class PrimitiveSet:
         """
         Add a symbolic terminal, whose name points to the true value stored in :attr:`globals`.
 
-        For example, we may add a terminal for the constant *pi*, with ``add_symbol_terminal(3.1415, 'pi')``.
+        For example, we may add a terminal for the constant *pi*, with ``add_symbol_terminal('pi', 3.14)``.
 
         :param name: name of the terminal
         :param value: value of the terminal
@@ -390,25 +394,36 @@ class PrimitiveSet:
         Python identifier. If the supplied *name* is acceptable, it is added to the :attr:`~PrimitiveSet._unique_names`
         attribute.
         """
-        assert name not in self._globals, "A primitive with the name '{}' already exists.".format(name)
+        assert name not in self._globals, "A primitive with the name '{}' already exists.".format(
+            name)
 
     def add_ephemeral_terminal(self, name, gen):
         """
-        Add an ephemeral constant to the set. An ephemeral's true value is generated by *gen*, which should be a no
-        argument function that returns a random value, when the ephemeral is picked to build a gene. Once an ephemeral
-        is picked, its :meth:`Ephemeral.generate` method is called to produce a random value.
-
-        In GEP, the ephemeral terminals (i.e., their values) can be evolved by simple mutation or advanced
-        local search optimization.
+        Add an ephemeral constant of type :class:`~geppy.core.symbol.EphemeralTerminal` to the set. 
+        An ephemeral's true value is generated by *gen*, which should be a 
+        zero-argument function that returns a random value, when the ephemeral is picked to build a gene. After that, 
+        the ephemeral's value is fixed.
+        
+        If you want to 
+        evolve its value actively, then the mutation operator :func:`~geppy.tools.mutation.mutate_uniform_ephemeral` should be 
+        used for ephemeral mutation. Of course, the value of an :class:`~geppy.core.symbol.EphemeralTerminal` instance
+        can also be set directly in more advanced algorithms, e.g., via local search optimization.
 
         :param name: str, name of the ephemeral
         :param gen: callable, a random number generator which returns a random constant when called by ``gen()``
 
         Usually calling :meth:`add_ephemeral_terminal` once is sufficient to generate the numerical coefficients in the
-        model, because during evolution multiple independent copies of the ephemeral terminal will be built with
-        various values.
+        model, because during evolution multiple independent copies of the ephemeral terminal will be constructed with
+        different values.
         Nevertheless, if the numerical coefficients have various ranges, it may be more efficient to add multiple
-        ephemeral terminals.
+        ephemeral terminals with corresponding generators.
+
+        .. note::
+            If the number of other kinds of terminals is very large, e.g., hundreds, then it is better to call this method 
+            multiple times even if with a single `gen`. The reason is that each terminal is chosen randomly and uniformly 
+            from the list of all terminals given by :meth:`terminals`, and the probability of picking an ephemeral terminal 
+            will become quite low if there is only a tiny number of ephemeral terminals but a large number of other terminals,
+            which contain typically input terminals.
 
         .. note::
             The special terminal named *ephemeral random constant* was originally introduced in genetic programming
@@ -434,7 +449,11 @@ class PrimitiveSet:
             the default value '?' is recommended.
 
         Usually it is sufficient to call this method once to add only one RNC terminal, since the values of the
-        RNC terminals at different positions are different random numerical constants..
+        RNC terminals at different positions are different random numerical constants.
+
+        .. note::
+            If the number of other kinds of terminals is very large, e.g., hundreds, then it is better to call this method 
+            multiple times. Please check the documentation of :meth:`add_ephemeral_terminal` for more details.
         """
         self._terminals.append(RNCTerminal(name))
 
